@@ -7,19 +7,17 @@ logger = logging.getLogger('dict_config_logger')
 
 def email_verification(email):
     """Function to send email verification"""
-    logger.info("Check if email id from user is verified")
-    # ses = boto3.client('ses')
-    # check = check_if_email_verified(email)
+    ses = boto3.client('ses')
+    check = check_if_email_verified(email)
 
-    # if check:
-    #     logger.error(str(email) + "Email is not verified")
-        # logger.info("Email is sent for Verification")
-        #
-        # response = ses.verify_email_identity(
-        #     EmailAddress=email
-        # )
-        #
-        # logger.info(response)
+    if check:
+        logger.info("Email is sent for Verification")
+
+        response = ses.verify_email_identity(
+            EmailAddress=email
+        )
+
+        logger.info(response)
 
 
 def check_if_email_verified(email):
